lxm3.xm\_cluster.GridEngine
===========================

.. currentmodule:: lxm3.xm_cluster

.. autoclass:: GridEngine

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GridEngine.__init__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~GridEngine.requirements
      ~GridEngine.resources
      ~GridEngine.parallel_environments
      ~GridEngine.walltime
      ~GridEngine.queue
      ~GridEngine.reserved
      ~GridEngine.log_directory
      ~GridEngine.merge_output
      ~GridEngine.shell
      ~GridEngine.project
      ~GridEngine.account
      ~GridEngine.modules
      ~GridEngine.max_parallel_tasks
      ~GridEngine.extra_directives
      ~GridEngine.skip_directives
      ~GridEngine.singularity_options
   
   